@@ -28,13 +28,10 @@ __license__                     = "Dual License: GPLv3 (or later) and Commercial
 Miscellaneous functionality used by various other modules.
 """
 
-import fcntl
 import functools
 import logging
 import math
 import os
-import signal
-import subprocess
 import sys
 import time
 import types
@@ -143,7 +140,7 @@ def change_function( function, **kwds ):
     # Enumerate  all the __code__ attributes in the same order; types.CodeTypes
     # doesn't accept keyword args, only position.
     attrs			= [ "co_argcount" ]
-    if sys.version_info.major >= 3:
+    if sys.version_info[0] >= 3:
         attrs		       += [ "co_kwonlyargcount" ]
     attrs		       += [ "co_nlocals",
                                     "co_stacksize",
@@ -390,9 +387,9 @@ def natural( string, fmt="%9s", ):
                    else itm )
                   for itm in res )
 
-natural.str_type 	= ( basestring if sys.version_info.major < 3
+natural.str_type 	= ( basestring if sys.version_info[0] < 3
                             else str )
-natural.num_types	= ( (float, int, long) if sys.version_info.major < 3
+natural.num_types	= ( (float, int, long) if sys.version_info[0] < 3
                             else (float, int))
 
 
@@ -468,60 +465,4 @@ def assert_tps( minimum=None, scale=None, repeat=1 ):
     return decorator
 
 
-class nonblocking_command( object ):
-    """Set up a non-blocking command producing output.  Read the output using:
-
-        collect 		= ''
-        while True:
-            if command is None:
-		# Restarts command on failure, for example
-    		command 	= nonblocking_command( ... )
-
-            try:
-                data 		= command.stdout.read()
-                logging.debug( "Received %d bytes from command, len( data ))
-                collect        += data
-            except IOError as exc:
-                if exc.errno != errno.EAGAIN:
-                    logging.warning( "I/O Error reading data: %s" % traceback.format_exc() )
-                    command	= None
-		# Data not presently available; ignore
-            except:
-                logging.warning( "Exception reading data: %s", traceback.format_exc() )
-                command		= None
-
-            # do other stuff in loop...
-
-    The command is killed when it goes out of scope.
-    """
-    def __init__( self, command ):
-
-        shell			= type( command ) is not list
-        self.command		= ' '.join( command ) if not shell else command
-        logging.info( "Starting command: %s", self.command )
-        self.process		= subprocess.Popen(
-            command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
-            preexec_fn=os.setsid, shell=shell )
-
-        fd 			= self.process.stdout.fileno()
-        fl			= fcntl.fcntl( fd, fcntl.F_GETFL )
-        fcntl.fcntl( fd, fcntl.F_SETFL, fl | os.O_NONBLOCK )
-
-    @property
-    def stdout( self ):
-        return self.process.stdout
-
-    def kill( self ):
-        logging.info( 'Sending SIGTERM to PID [%d]: %s', self.process.pid, self.command )
-        try:
-            os.killpg( self.process.pid, signal.SIGTERM )
-        except OSError as exc:
-            logging.info( 'Failed to send SIGTERM to PID [%d]: %s', self.process.pid, exc )
-        else:
-            logging.info( "Waiting for command (PID [%d]) to terminate", self.process.pid )
-            self.process.wait()
-
-        logging.info("Command (PID [%d]) finished with status [%d]: %s", self.process.pid, self.process.returncode, self.command )
-
-    __del__			= kill
 
